@@ -28,6 +28,9 @@ class ApolloEnvParam(AbstractModel):
         :param Name: 环境名称
         :type Name: str
         :param EngineResourceSpec: 环境内引擎的节点规格 ID
+-1C2G
+-2C4G
+兼容原spec-xxxxxx形式的规格ID
         :type EngineResourceSpec: str
         :param EngineNodeNum: 环境内引擎的节点数量
         :type EngineNodeNum: int
@@ -37,6 +40,8 @@ class ApolloEnvParam(AbstractModel):
         :type VpcId: str
         :param SubnetId: 子网 ID。在 VPC 的子网内分配一个 IP 作为 ConfigServer 的访问地址
         :type SubnetId: str
+        :param EnvDesc: 环境描述
+        :type EnvDesc: str
         """
         self.Name = None
         self.EngineResourceSpec = None
@@ -44,6 +49,7 @@ class ApolloEnvParam(AbstractModel):
         self.StorageCapacity = None
         self.VpcId = None
         self.SubnetId = None
+        self.EnvDesc = None
 
 
     def _deserialize(self, params):
@@ -53,6 +59,7 @@ class ApolloEnvParam(AbstractModel):
         self.StorageCapacity = params.get("StorageCapacity")
         self.VpcId = params.get("VpcId")
         self.SubnetId = params.get("SubnetId")
+        self.EnvDesc = params.get("EnvDesc")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -96,6 +103,34 @@ class BoundK8SInfo(AbstractModel):
         
 
 
+class CloudNativeAPIGatewayNode(AbstractModel):
+    """云原生API网关节点信息。
+
+    """
+
+    def __init__(self):
+        r"""
+        :param NodeId: 云原生网关节点 id
+        :type NodeId: str
+        :param NodeIp: 节点 ip
+        :type NodeIp: str
+        """
+        self.NodeId = None
+        self.NodeIp = None
+
+
+    def _deserialize(self, params):
+        self.NodeId = params.get("NodeId")
+        self.NodeIp = params.get("NodeIp")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class CreateEngineRequest(AbstractModel):
     """CreateEngine请求参数结构体
 
@@ -118,12 +153,17 @@ class CreateEngineRequest(AbstractModel):
 
 引擎各版本及可选择的规格、节点数说明：
 apollo - STANDARD版本
-规格列表：spec-qcr53kf1t（1C2G）,spec-qdr53kf2w（2C4G）
+规格列表：1C2G、2C4G、4C8G、8C16G、16C32G
 节点数：1，2，3，4，5
 
 eureka - STANDARD版本
-规格列表：spec-qvj6k7t4q（1C2G）,spec-qcr53kfjt（2C4G）,spec-qvj6k7t4m（4G8G）,spec-qcr54kfjt（8C16G）,spec-qcr55kfjt（16C32G）
+规格列表：1C2G、2C4G、4C8G、8C16G、16C32G
 节点数：3，4，5
+
+polarismesh - STANDARD版本
+规格列表：NUM50、NUM100、NUM200、NUM500、NUM1000、NUM5000、NUM10000、NUM50000
+
+兼容原spec-xxxxxx形式的规格ID
         :type EngineProductVersion: str
         :param EngineRegion: 引擎所在地域。参考值说明：
 中国区 参考值：
@@ -150,7 +190,7 @@ eureka - STANDARD版本
         :type EngineName: str
         :param TradeType: 付费类型。参考值：
 - 0：后付费
-- 1：预付费
+- 1：预付费（接口暂不支持创建预付费实例）
         :type TradeType: int
         :param EngineResourceSpec: 引擎的节点规格 ID。参见EngineProductVersion字段说明
         :type EngineResourceSpec: str
@@ -301,6 +341,148 @@ class DeleteEngineResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DescribeCloudNativeAPIGatewayNodesRequest(AbstractModel):
+    """DescribeCloudNativeAPIGatewayNodes请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param GatewayId: 云原生API网关实例ID。
+        :type GatewayId: str
+        :param GroupId: 实例分组id
+        :type GroupId: str
+        :param Limit: 翻页获取多少个
+        :type Limit: int
+        :param Offset: 翻页从第几个开始获取
+        :type Offset: int
+        """
+        self.GatewayId = None
+        self.GroupId = None
+        self.Limit = None
+        self.Offset = None
+
+
+    def _deserialize(self, params):
+        self.GatewayId = params.get("GatewayId")
+        self.GroupId = params.get("GroupId")
+        self.Limit = params.get("Limit")
+        self.Offset = params.get("Offset")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class DescribeCloudNativeAPIGatewayNodesResponse(AbstractModel):
+    """DescribeCloudNativeAPIGatewayNodes返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Result: 获取云原生网关节点列表结果。
+        :type Result: :class:`tencentcloud.tse.v20201207.models.DescribeCloudNativeAPIGatewayNodesResult`
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.Result = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        if params.get("Result") is not None:
+            self.Result = DescribeCloudNativeAPIGatewayNodesResult()
+            self.Result._deserialize(params.get("Result"))
+        self.RequestId = params.get("RequestId")
+
+
+class DescribeCloudNativeAPIGatewayNodesResult(AbstractModel):
+    """获取网关节点信息
+
+    """
+
+    def __init__(self):
+        r"""
+        :param TotalCount: 获取云原生API网关节点列表响应结果。
+        :type TotalCount: int
+        :param NodeList: 云原生API网关节点列表。
+        :type NodeList: list of CloudNativeAPIGatewayNode
+        """
+        self.TotalCount = None
+        self.NodeList = None
+
+
+    def _deserialize(self, params):
+        self.TotalCount = params.get("TotalCount")
+        if params.get("NodeList") is not None:
+            self.NodeList = []
+            for item in params.get("NodeList"):
+                obj = CloudNativeAPIGatewayNode()
+                obj._deserialize(item)
+                self.NodeList.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class DescribeInstanceRegionInfo(AbstractModel):
+    """实例地域信息描述
+
+    """
+
+    def __init__(self):
+        r"""
+        :param EngineRegion: 引擎部署地域信息
+注意：此字段可能返回 null，表示取不到有效值。
+        :type EngineRegion: str
+        :param Replica: 引擎在该地域的副本数
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Replica: int
+        :param SpecId: 引擎在该地域的规格id
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SpecId: str
+        :param IntranetVpcInfos: 内网的网络信息
+注意：此字段可能返回 null，表示取不到有效值。
+        :type IntranetVpcInfos: list of VpcInfo
+        :param EnableClientInternet: 是否开公网
+注意：此字段可能返回 null，表示取不到有效值。
+        :type EnableClientInternet: bool
+        """
+        self.EngineRegion = None
+        self.Replica = None
+        self.SpecId = None
+        self.IntranetVpcInfos = None
+        self.EnableClientInternet = None
+
+
+    def _deserialize(self, params):
+        self.EngineRegion = params.get("EngineRegion")
+        self.Replica = params.get("Replica")
+        self.SpecId = params.get("SpecId")
+        if params.get("IntranetVpcInfos") is not None:
+            self.IntranetVpcInfos = []
+            for item in params.get("IntranetVpcInfos"):
+                obj = VpcInfo()
+                obj._deserialize(item)
+                self.IntranetVpcInfos.append(obj)
+        self.EnableClientInternet = params.get("EnableClientInternet")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class DescribeNacosReplicasRequest(AbstractModel):
     """DescribeNacosReplicas请求参数结构体
 
@@ -439,16 +621,24 @@ class DescribeSREInstanceAccessAddressRequest(AbstractModel):
         :type VpcId: str
         :param SubnetId: 子网ID
         :type SubnetId: str
+        :param Workload: 引擎其他组件名称（pushgateway、polaris-limiter）
+        :type Workload: str
+        :param EngineRegion: 部署地域
+        :type EngineRegion: str
         """
         self.InstanceId = None
         self.VpcId = None
         self.SubnetId = None
+        self.Workload = None
+        self.EngineRegion = None
 
 
     def _deserialize(self, params):
         self.InstanceId = params.get("InstanceId")
         self.VpcId = params.get("VpcId")
         self.SubnetId = params.get("SubnetId")
+        self.Workload = params.get("Workload")
+        self.EngineRegion = params.get("EngineRegion")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -483,6 +673,9 @@ class DescribeSREInstanceAccessAddressResponse(AbstractModel):
         :param ConsoleInternetBandWidth: 控制台公网带宽
 注意：此字段可能返回 null，表示取不到有效值。
         :type ConsoleInternetBandWidth: int
+        :param LimiterAddressInfos: 北极星限流server节点接入IP
+注意：此字段可能返回 null，表示取不到有效值。
+        :type LimiterAddressInfos: list of PolarisLimiterAddress
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -493,6 +686,7 @@ class DescribeSREInstanceAccessAddressResponse(AbstractModel):
         self.ConsoleIntranetAddress = None
         self.InternetBandWidth = None
         self.ConsoleInternetBandWidth = None
+        self.LimiterAddressInfos = None
         self.RequestId = None
 
 
@@ -509,6 +703,12 @@ class DescribeSREInstanceAccessAddressResponse(AbstractModel):
         self.ConsoleIntranetAddress = params.get("ConsoleIntranetAddress")
         self.InternetBandWidth = params.get("InternetBandWidth")
         self.ConsoleInternetBandWidth = params.get("ConsoleInternetBandWidth")
+        if params.get("LimiterAddressInfos") is not None:
+            self.LimiterAddressInfos = []
+            for item in params.get("LimiterAddressInfos"):
+                obj = PolarisLimiterAddress()
+                obj._deserialize(item)
+                self.LimiterAddressInfos.append(obj)
         self.RequestId = params.get("RequestId")
 
 
@@ -757,16 +957,26 @@ class EnvAddressInfo(AbstractModel):
         :type EnableConfigInternet: bool
         :param ConfigInternetServiceIp: config公网ip
         :type ConfigInternetServiceIp: str
+        :param ConfigIntranetAddress: config内网访问地址
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ConfigIntranetAddress: str
+        :param EnableConfigIntranet: 是否开启config内网clb
+注意：此字段可能返回 null，表示取不到有效值。
+        :type EnableConfigIntranet: bool
         """
         self.EnvName = None
         self.EnableConfigInternet = None
         self.ConfigInternetServiceIp = None
+        self.ConfigIntranetAddress = None
+        self.EnableConfigIntranet = None
 
 
     def _deserialize(self, params):
         self.EnvName = params.get("EnvName")
         self.EnableConfigInternet = params.get("EnableConfigInternet")
         self.ConfigInternetServiceIp = params.get("ConfigInternetServiceIp")
+        self.ConfigIntranetAddress = params.get("ConfigIntranetAddress")
+        self.EnableConfigIntranet = params.get("EnableConfigIntranet")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -807,6 +1017,10 @@ class EnvInfo(AbstractModel):
         :type RunningCount: int
         :param AliasEnvName: 环境别名
         :type AliasEnvName: str
+        :param EnvDesc: 环境描述
+        :type EnvDesc: str
+        :param ClientBandWidth: 客户端带宽
+        :type ClientBandWidth: int
         """
         self.EnvName = None
         self.VpcInfos = None
@@ -820,6 +1034,8 @@ class EnvInfo(AbstractModel):
         self.EnvReplica = None
         self.RunningCount = None
         self.AliasEnvName = None
+        self.EnvDesc = None
+        self.ClientBandWidth = None
 
 
     def _deserialize(self, params):
@@ -840,6 +1056,8 @@ class EnvInfo(AbstractModel):
         self.EnvReplica = params.get("EnvReplica")
         self.RunningCount = params.get("RunningCount")
         self.AliasEnvName = params.get("AliasEnvName")
+        self.EnvDesc = params.get("EnvDesc")
+        self.ClientBandWidth = params.get("ClientBandWidth")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1005,6 +1223,31 @@ class NacosServerInterface(AbstractModel):
         
 
 
+class PolarisLimiterAddress(AbstractModel):
+    """查询Limiter的接入地址
+
+    """
+
+    def __init__(self):
+        r"""
+        :param IntranetAddress: VPC接入IP列表
+注意：此字段可能返回 null，表示取不到有效值。
+        :type IntranetAddress: str
+        """
+        self.IntranetAddress = None
+
+
+    def _deserialize(self, params):
+        self.IntranetAddress = params.get("IntranetAddress")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class SREInstance(AbstractModel):
     """微服务注册引擎实例
 
@@ -1091,6 +1334,9 @@ class SREInstance(AbstractModel):
         :param IsolateTime: 隔离开始时间
 注意：此字段可能返回 null，表示取不到有效值。
         :type IsolateTime: str
+        :param RegionInfos: 实例地域相关的描述信息
+注意：此字段可能返回 null，表示取不到有效值。
+        :type RegionInfos: list of DescribeInstanceRegionInfo
         """
         self.InstanceId = None
         self.Name = None
@@ -1121,6 +1367,7 @@ class SREInstance(AbstractModel):
         self.AutoRenewFlag = None
         self.CurDeadline = None
         self.IsolateTime = None
+        self.RegionInfos = None
 
 
     def _deserialize(self, params):
@@ -1173,6 +1420,12 @@ class SREInstance(AbstractModel):
         self.AutoRenewFlag = params.get("AutoRenewFlag")
         self.CurDeadline = params.get("CurDeadline")
         self.IsolateTime = params.get("IsolateTime")
+        if params.get("RegionInfos") is not None:
+            self.RegionInfos = []
+            for item in params.get("RegionInfos"):
+                obj = DescribeInstanceRegionInfo()
+                obj._deserialize(item)
+                self.RegionInfos.append(obj)
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1201,6 +1454,10 @@ class ServiceGovernanceInfo(AbstractModel):
         :type Features: list of str
         :param MainPassword: 主账户名默认为 polaris，该值为主账户的默认密码
         :type MainPassword: str
+        :param PgwVpcInfos: 服务治理pushgateway引擎绑定的网络信息
+        :type PgwVpcInfos: list of VpcInfo
+        :param LimiterVpcInfos: 服务治理限流server引擎绑定的网络信息
+        :type LimiterVpcInfos: list of VpcInfo
         """
         self.EngineRegion = None
         self.BoundK8SInfos = None
@@ -1208,6 +1465,8 @@ class ServiceGovernanceInfo(AbstractModel):
         self.AuthOpen = None
         self.Features = None
         self.MainPassword = None
+        self.PgwVpcInfos = None
+        self.LimiterVpcInfos = None
 
 
     def _deserialize(self, params):
@@ -1227,6 +1486,18 @@ class ServiceGovernanceInfo(AbstractModel):
         self.AuthOpen = params.get("AuthOpen")
         self.Features = params.get("Features")
         self.MainPassword = params.get("MainPassword")
+        if params.get("PgwVpcInfos") is not None:
+            self.PgwVpcInfos = []
+            for item in params.get("PgwVpcInfos"):
+                obj = VpcInfo()
+                obj._deserialize(item)
+                self.PgwVpcInfos.append(obj)
+        if params.get("LimiterVpcInfos") is not None:
+            self.LimiterVpcInfos = []
+            for item in params.get("LimiterVpcInfos"):
+                obj = VpcInfo()
+                obj._deserialize(item)
+                self.LimiterVpcInfos.append(obj)
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1236,6 +1507,55 @@ class ServiceGovernanceInfo(AbstractModel):
         
 
 
+class UpdateEngineInternetAccessRequest(AbstractModel):
+    """UpdateEngineInternetAccess请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param InstanceId: 引擎ID
+        :type InstanceId: str
+        :param EngineType: 引擎类型
+        :type EngineType: str
+        :param EnableClientInternetAccess: 是否开启客户端公网访问，true开 false关
+        :type EnableClientInternetAccess: bool
+        """
+        self.InstanceId = None
+        self.EngineType = None
+        self.EnableClientInternetAccess = None
+
+
+    def _deserialize(self, params):
+        self.InstanceId = params.get("InstanceId")
+        self.EngineType = params.get("EngineType")
+        self.EnableClientInternetAccess = params.get("EnableClientInternetAccess")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class UpdateEngineInternetAccessResponse(AbstractModel):
+    """UpdateEngineInternetAccess返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class VpcInfo(AbstractModel):
     """私有网络信息
 
@@ -1291,6 +1611,9 @@ class ZookeeperReplica(AbstractModel):
         :param ZoneId: 可用区ID
 注意：此字段可能返回 null，表示取不到有效值。
         :type ZoneId: str
+        :param AliasName: 别名
+注意：此字段可能返回 null，表示取不到有效值。
+        :type AliasName: str
         """
         self.Name = None
         self.Role = None
@@ -1298,6 +1621,7 @@ class ZookeeperReplica(AbstractModel):
         self.SubnetId = None
         self.Zone = None
         self.ZoneId = None
+        self.AliasName = None
 
 
     def _deserialize(self, params):
@@ -1307,6 +1631,7 @@ class ZookeeperReplica(AbstractModel):
         self.SubnetId = params.get("SubnetId")
         self.Zone = params.get("Zone")
         self.ZoneId = params.get("ZoneId")
+        self.AliasName = params.get("AliasName")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
